computeC: computeC: perform correlation analyses between individual...

Description Usage Arguments Author(s) References Examples

View source: R/computeC.R

Description

Automatically perform correlation analyses between individual genes and each clinical feature of your interest. For further information on requirements as well as how to implement this tool, please visit my Github repository: https://github.com/huynguyen250896/computeC.

Usage

1
computeC(data,clinical,col, methodCC)

Arguments

data

data frame or matrix. The data represents its rows are samples and its columns are genomic features.

clinical

data frame. The data represents its rows are samples and its columns are clinical features. Note that samples are also included in rows of data and in the same order.

col

character. Name of any columns in clinical. This must be a clinical feature that you are interest.

methodCC

Correlation method. Allowed values are spearman (default), pearson, kendall.

Author(s)

Quang-Huy Nguyen

References

Quang-Huy Nguyen, Duc-Hau Le. (2020). Improving existing analysis pipeline to identify and analyze cancer driver genes using multi-omics data. Scientific Reports, 10(1):20521.

Examples

1
2
3
4
computeC(data = exp, clinical = cli, col = "lymph")
#data = exp => gene expression
#col = "lymph" => association between the expression levels of each gene 
#versus the number of lymph nodes of breast cancer patients.

huynguyen250896/computeC documentation built on June 24, 2021, 5:58 a.m.