Description Usage Arguments Author(s) References Examples
Automatically perform correlation analyses between individual genes and each clinical feature of your interest. For further information on requirements as well as how to implement this tool, please visit my Github repository: https://github.com/huynguyen250896/computeC.
1 |
data |
data frame or matrix. The data represents its rows are samples and its columns are genomic features. |
clinical |
data frame. The data represents its rows are samples and its columns are clinical features. Note that
samples are also included in rows of |
col |
character. Name of any columns in |
methodCC |
Correlation method. Allowed values are |
Quang-Huy Nguyen
Quang-Huy Nguyen, Duc-Hau Le. (2020). Improving existing analysis pipeline to identify and analyze cancer driver genes using multi-omics data. Scientific Reports, 10(1):20521.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.